#!/bin/bash
#
#   USAGE:  build_cmake.sh <product_dir> [tar]
#   NOTE:  we build cmake with the native compiler

usage()
{
   echo "USAGE: `basename ${0}` <product_dir> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`

    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=cmake
origpkgver=v3_9_2
pkgver=${origpkgver}
ssibuildshims_version=v1_00_00
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`

get_this_dir

get_ssibuildshims

source define_basics NO_QUAL NO_DEBUG_SOURCE

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/bin ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
    exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi
mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${sourcedir}
if [ ! -d ${sourcedir} ]
then
   echo "ERROR: failed to create ${sourcedir}"
   exit 1
fi

set -x

cd ${sourcedir}
tar xf ${tardir}/cmake-${pkgdotver}.tar.gz || ssi_die "Unable to unwind ${tardir}/cmake-${pkgdotver}.tar.gz"
patch=${patchdir}/cmake-boost.patch
patch ${DEBUG_PATCHES:+--verbose} -b -p0 < "${patch}" || ssi_die "application of patch ${patch} failed."

[[ -n "${DEBUG_PATCHES}" ]] && exit 1

ncores=$(${SSIBUILDSHIMS_DIR}/bin/ncores)

cd ${blddir}
${sourcedir}/${package}-${pkgdotver}/bootstrap --prefix=${pkgdir} --parallel=${ncores}
make -j ${ncores} || ssi_die "make failed"
# ctest -j ${ncores} || ssi_die "tests failed"
make -j ${ncores} install  || ssi_die "'make install' failed"

set +x

if [ ! -d ${pkgdir}/bin ]
then
   echo "ERROR: failed to create ${pkgdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi

ups exist ${package} ${pkgver} -z ${product_dir} || \
  ${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL || \
  ssi_die "Unable to declare product to UPS."

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir} || \
  ssi_die "unable to set up newly-built product."
which cmake

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/bin ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
fi

exit 0
